@@ -1,29 +1,3 @@
-#' Source all .R files under data-raw/
-#'
-#' Usually we work on one dataset only, and don't know if our change impacted
-#' other datasets. This function helps "refresh" all datasets at once. It may
-#' be used interactively while developing the package, or in CI to regularly
-#' check we can reproduce all datasets we export, and that the result is
-#' consistent with our regression tests.
-#'
-#' @return `invisible()`, as it's called for its side effect.
-#' @keywords internal
-#'
-#' @examples
-#' source_data_raw()
-#' @noRd
-source_data_raw <- function(path = "data-raw") {
-  lapply(r_files_in(path), source)
-
-  invisible(path)
-}
-
-r_files_in <- function(path) {
-  # pattern = "[.]R$" is simpler but platform-inconsistent, e.g. "a//b", "a/b".
-  path_ext <- list.files(path, pattern = NULL, full.names = TRUE)
-  grep("[.]R$", path_ext, value = TRUE)
-}
-
 #' Create a list of all or some datasets exported by a package
 #'
 #' @param package A character string of length-1 giving the name of a package.
